#!/usr/bin/env python
# das.py

"""
Author : peters 

Revision History:
File created on 29 Sep 2009.

"""
if __name__ == "__main__":
    import sys
    import os
    import logging
    import shutil

# Append current working dir to path

    sys.path.append(os.getcwd())

# Import methods and classes contained in this package

    from da.tools.initexit import CleanUpCycle
    from da.tools.initexit import ValidateOptsArgs
    from da.tools.initexit import ParseOptions
    from da.tools.initexit import StartLogger
    from da.tools.pipeline import *
    from da.tools.general import StoreData,RestoreData
    
# Start a logger for all that happens from here on
    
    dummy   = StartLogger()

# Parse options from the command line

    opts, args = ParseOptions()

# Validate Options and arguments passed

    opts,args   = ValidateOptsArgs(opts,args)

    process     = args['process'].lower()

# Create the Cycle Control object for this job    
    msg          = header+"Initializing Job"+footer           ; logging.info(msg) 

    DaCycle      = JobStart(opts,args)
    dummy        = DaCycle.Initialize()

    savefilename = os.path.join(DaCycle.da_settings['dir.save'],'statevector.pickle')

# Start the requested subprocesses

    if process == 'start':

        msg          = header+"starting JobInput"+footer           ; logging.info(msg) 

        StateVector  = JobInput(DaCycle)

        StateVector  = StoreData(StateVector,savefilename)

        dummy        = DaCycle.SubmitSubStep('samplestate')

    if process == 'samplestate':
        msg          = header+"starting SampleState"+footer         ; logging.info(msg) 

        StateVector  = RestoreData(savefilename)

        dummy        = SampleState(DaCycle,StateVector)

        dummy        = StoreData(StateVector,savefilename)

        dummy        = DaCycle.SubmitSubStep('invert')

    if process == 'invert':
        msg          = header+"starting Invert"+footer             ; logging.info(msg) 

        StateVector  = RestoreData(savefilename)

        dummy        = Invert(DaCycle, StateVector)

        StateVector  = StoreData(StateVector,savefilename)

        dummy        = DaCycle.SubmitSubStep('advance')


    if process == 'advance':
        msg          = header+"starting Advance"+footer          ; logging.info(msg) 

        StateVector  = RestoreData(savefilename)

        dummy        = Advance(DaCycle, StateVector)

        StateVector  = StoreData(StateVector,savefilename)

        dummy        = DaCycle.SubmitSubStep('done')

    if process == 'done':
        msg          = header+"starting SaveAndSubmit"+footer      ; logging.info(msg) 

        StateVector  = RestoreData(savefilename)

        dummy        = SaveAndSubmit(DaCycle, StateVector)

        msg          = "Cycle finished...exiting"     ; logging.info(msg)

        dummy        = CleanUpCycle(DaCycle)

    sys.exit(0)
